@@ -1,19 +1,17 @@
-use crate::audio::{
-    spsc::{self, Producer},
-    Mixer, SoundInstance,
-};
+use crate::audio::{Mixer, SoundInstance};
+use crate::sync::{make as spsc_make, Producer};
 use cpal::{
     traits::{DeviceTrait, HostTrait, StreamTrait},
     Stream,
 };
 
-pub struct AudioState {
+pub(crate) struct AudioState {
     sender: Producer<SoundInstance>,
     stream: Stream,
 }
 
 impl AudioState {
-    pub fn init() -> AudioState {
+    pub(crate) fn init() -> AudioState {
         let host = cpal::default_host();
         let device = host.default_output_device().expect("no output device available");
         let sample_rate = device.default_output_config().unwrap().sample_rate();
@@ -22,7 +20,7 @@ impl AudioState {
             sample_rate,
             buffer_size: cpal::BufferSize::Default,
         };
-        let (sender, receiver) = spsc::make(256);
+        let (sender, receiver) = spsc_make(256);
         let mut mixer = Mixer::new(sample_rate.0, receiver);
 
         let stream = device
@@ -44,11 +42,11 @@ impl AudioState {
         }
     }
 
-    pub fn send(&mut self, instance: SoundInstance) {
+    pub(crate) fn push_sound(&mut self, instance: SoundInstance) {
         self.sender.push(instance);
     }
 }
 
 fn as_stereo(xs: &mut [f32]) -> &mut [[f32; 2]] {
-    unsafe { std::slice::from_raw_parts_mut(xs.as_mut_ptr() as _, xs.len() / 2) }
+    unsafe { core::slice::from_raw_parts_mut(xs.as_mut_ptr() as _, xs.len() / 2) }
 }
